@@ -6,9 +6,7 @@ import pprint
 import sys
 import time
 from os import environ as env
-from signal import SIGINT, signal
-
-import soco
+from signal import SIGINT, SIGTERM, signal
 
 from soco_cli.action_processor import list_actions
 from soco_cli.aliases import AliasManager
@@ -50,8 +48,6 @@ ENV_LOCAL = "USE_LOCAL_SPKR_CACHE"
 
 
 def main():
-    # Handle SIGINT
-    signal(SIGINT, sig_handler)
 
     # Create the argument parser
     parser = argparse.ArgumentParser(
@@ -132,6 +128,11 @@ def main():
 
     configure_logging(args.log)
 
+    signals = [SIGINT, SIGTERM]
+    logging.info("Setting up handlers for: {}".format(signals))
+    for sig in signals:
+        signal(sig, sig_handler)
+
     if args.version:
         version()
         exit(0)
@@ -474,7 +475,7 @@ def main():
                     cumulative_exit_code += exit_code
 
         except Exception as e:
-            print("Error: ", str(e), flush=True)
+            print("Error:", str(e), flush=True)
             cumulative_exit_code += 1
 
         sequence_pointer += 1
