@@ -15,9 +15,9 @@ from collections.abc import Sequence
 from platform import python_version
 from time import sleep
 
-import soco
+import soco  # type: ignore
 
-from soco_cli.__init__ import __version__
+from soco_cli.__init__ import __version__  # type: ignore
 from soco_cli.match_speaker_names import speaker_name_matches
 from soco_cli.speakers import Speakers
 
@@ -302,8 +302,8 @@ def sig_handler(signal_received, frame):
                 print(flush=True)
             return
 
-    # Allow SIGTERM termination, but issue warning
-    if signal_received == signal.SIGTERM:
+    # Allow SIGTERM termination, but issue warning if interactive
+    if signal_received == signal.SIGTERM and INTERACTIVE:
         print("\nSoCo-CLI process terminating ...", flush=True)
         print(
             "This can leave some terminals in a misconfigured state.",
@@ -321,8 +321,8 @@ def sig_handler(signal_received, frame):
     logging.info("Unsubscribing from event notifications")
     unsub_all_remembered_event_subs()
 
-    print("", flush=True)
     logging.info("Exiting program using 'os._exit(0)'")
+    print("", flush=True)
     os._exit(0)
 
 
